===============================
 Invenio-PIDRelations v1.0.0a1
===============================

Invenio-PIDRelations v1.0.0a1 was released on May 16, 2017.

About
-----

Invenio module that adds PID relations to the Invenio-PIDStore module.

*This is an experimental developer preview release.*

What's new
----------

- Initial public release.

Installation
------------

   $ pip install invenio-pidrelations==1.0.0a1

Documentation
-------------

   https://invenio-pidrelations.readthedocs.io/

Happy hacking and thanks for flying Invenio-PIDRelations.

| Invenio Development Team
|   Email: info@inveniosoftware.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: https://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-pidrelations
|   URL: http://inveniosoftware.org
